@@ -11,6 +11,9 @@ class Nsfw(Enum):
 
     Enumerator representing nsfw stages:
 
+    * **WHITE** - White
+    * **GRAY** - Gray
+    * **BLACK** - Black
     """
     WHITE = 'white'
     GRAY = 'gray'
@@ -22,6 +25,17 @@ class RelationType(Enum):
 
     Enumerator representing possible relation types between anime and/or manga:
 
+    * **SEQUEL** - Sequel
+    * **PREQUEL** - Prequel
+    * **ALT_SETTING** - Alternative Setting
+    * **ALT_VERSION** - Alternative Version
+    * **SIDE_STORY** - Side Story
+    * **PARENT_STORY** - Parent Story
+    * **SUMMARY** - Summary
+    * **FULL_STORY** - Full Story
+    * **SPIN_OFF** - Spin-Off
+    * **CHARACTER** - Character
+    * **OTHER** - Other
     """
     SEQUEL = "sequel"
     PREQUEL = "prequel"
@@ -40,6 +54,7 @@ class AnimeRankingType(Enum):
     """
 
     Representation of possible values for anime ranking type
+
     * **ALL** - Top Anime Series
     * **AIRING** - Top Airing Anime
     * **UPCOMING** - Top Upcoming Anime
@@ -65,6 +80,7 @@ class MangaRankingType(Enum):
     """
 
     Representation of possible values for manga ranking type
+
     * **ALL** - All
     * **MANGA** - Top Manga
     * **NOVELS** - Top Novels
@@ -90,6 +106,7 @@ class SeasonalAnimeSorting(Enum):
     """
 
     Representation of seasonal anime sorting
+
     * **SCORE** - Sorted by score
     * **USER_NUM** - Sorted by number of users in list
     """
@@ -101,6 +118,7 @@ class MyAnimeListSorting(Enum):
     """
 
     Sorting options for User Anime List
+
     * **LIST_SCORE** - Sorted by score given by user
     * **LAST_UPDATE** - Sorted by most recently updated
     * **TITLE** - Sorted by title
@@ -111,13 +129,14 @@ class MyAnimeListSorting(Enum):
     LAST_UPDATE = 'list_updated_at'
     TITLE = "anime_title"
     START_DATE = "anime_start_date"
-    ID = "anime_id"
+    # ID = "anime_id"
 
 
 class MyMangaListSorting(Enum):
     """
 
     Sorting options for User Manga List
+
     * **LIST_SCORE** - Sorted by score given by user
     * **LAST_UPDATE** - Sorted by most recently updated
     * **TITLE** - Sorted by title
@@ -128,7 +147,7 @@ class MyMangaListSorting(Enum):
     LAST_UPDATE = 'list_updated_at'
     TITLE = "manga_title"
     START_DATE = "manga_start_date"
-    ID = "manga_id"
+    # ID = "manga_id"
 
 
 class Rating(Enum):
@@ -163,6 +182,9 @@ class AnimeStatus(Enum):
 
     Enumerating representing current anime status
 
+    * **FINISHED** - Finished Airing
+    * **AIRING** - Currently Airing
+    * **NOT_AIRED** - Not Yet Aired
     """
     FINISHED = 'finished_airing'
     AIRING = 'currently_airing'
@@ -174,10 +196,17 @@ class MangaStatus(Enum):
 
     Enumerating representing current manga status
 
+    * **FINISHED** - Finished
+    * **PUBLISHING** - Currently Publishing
+    * **NOT_PUBLISHED** - Not Yet Published
+    * **ON_HIATUS** - On Break
+    * **DISCONTINUED** - Discontinued
     """
     FINISHED = 'finished'
     PUBLISHING = 'currently_publishing'
     NOT_PUBLISHED = 'not_yet_published'
+    ON_HIATUS = 'on_hiatus'
+    DISCONTINUED = 'discontinued'
 
 
 class AnimeType(Enum):
@@ -186,12 +215,12 @@ class AnimeType(Enum):
     Enumerator representing anime type:
 
     * **Unknown**
-    * **TV** - streamed in Japanese TV
+    * **TV** - Streamed in Japanese TV
     * **OVA** - Original Video Animation
-    * **Movie** - animated movie
-    * **Special** - special for anime
-    * **ONA** - Original Net Anime
-    * **Music** - music anime
+    * **Movie** - Animated Movie
+    * **Special** - Special for an anime
+    * **ONA** - Original Net Anime (f.e. Netflix Originals)
+    * **Music** - Music Anime
     """
     UNKNOWN = "unknown"
     TV = "tv"
@@ -199,7 +228,7 @@ class AnimeType(Enum):
     MOVIE = 'movie'
     SPECIAL = 'special'
     ONA = 'ona'
-    MUSIC = 'Music'
+    MUSIC = 'music'
 
 
 class MangaType(Enum):
@@ -207,13 +236,14 @@ class MangaType(Enum):
 
     Enumerator representing type of manga
 
-    * **UNKNOWN**
-    * **MANGA**
-    * **NOVEL**
-    * **ONE_SHOT**
-    * **DOUJIN** - self-published manga
+    * **UNKNOWN** - Unknown
+    * **MANGA** - Manga
+    * **NOVEL** - Novel
+    * **ONE_SHOT** = One-Shot
+    * **DOUJIN** - Self-published Manga
     * **MANHWA** - Korean comic
     * **MANHUA** - Chinese comic
+    * **LIGHT_NOVEL** - Light Novel
     * **OEL** - Original English-Language Manga
     """
     UNKNOWN = "unknown"
@@ -224,12 +254,31 @@ class MangaType(Enum):
     MANHWA = "manhwa"
     MANHUA = "manhua"
     OEL = "oel"
+    LIGHT_NOVEL = 'light_novel'
 
 
 class AnimeSource(Enum):
     """
 
     Enumerator representing source of anime
+    
+    * **OTHER** - Other
+    * **ORIGINAL** - Original
+    * **MANGA** - Manga
+    * **MANGA_4_KOMA** - 4-Koma, comedic manga format
+    * **WEB_MANGA** - Web Manga
+    * **WEB_NOVEL** - Web Novel
+    * **DIGITAL_MANGA** - Digital Manga
+    * **NOVEL** - Novel
+    * **LIGHT_NOVEL** - Light Novel
+    * **VISUAL_NOVEL** - Text-based video game
+    * **GAME** - Game
+    * **CARD_GAME** - Card Game
+    * **BOOK** - Book
+    * **PICTURE_BOOK** - Picture Book
+    * **RADIO** - Radio
+    * **MUSIC** - Music
+    * **MIXED_MEDIA** - Mixed Media
 
     """
     OTHER = "other"
@@ -237,6 +286,7 @@ class AnimeSource(Enum):
     MANGA = "manga"
     MANGA_4_KOMA = "4_koma_manga"
     WEB_MANGA = "web_manga"
+    WEB_NOVEL = "web_novel"
     DIGITAL_MANGA = "digital_manga"
     NOVEL = "novel"
     LIGHT_NOVEL = "light_novel"
@@ -247,3 +297,4 @@ class AnimeSource(Enum):
     PICTURE_BOOK = "picture_book"
     RADIO = "radio"
     MUSIC = "music"
+    MIXED_MEDIA = "mixed_media"
