@@ -1,7 +1,7 @@
 from types import MethodType, MethodWrapperType, BuiltinFunctionType
 from typing import Union
 
-__all__ = ['Fields', 'AuthorFields', 'ListStatusFields']
+__all__ = ['Fields', 'AuthorFields', 'ListStatusFields', 'UserFields']
 
 
 class FieldsBase(object):
@@ -44,6 +44,10 @@ class FieldsBase(object):
                 fields.append(field)
         return ','.join(fields)
 
+    def _generate_subclass(self, r_type, kwargs, key):
+        return r_type(**kwargs.get(key)) if isinstance(kwargs.get(key), dict) else kwargs.get(key) if isinstance(
+            kwargs.get(key), r_type) else False if kwargs.get(key) is not True else r_type()
+
     @classmethod
     def from_list(cls, field_list: list[str]):
         """
@@ -88,7 +92,8 @@ class Fields(FieldsBase):
         self.num_scoring_users: bool = kwargs.get('num_scoring_users', False)
         self.updated_at: bool = kwargs.get('updated_at', False)
         self.genres: bool = kwargs.get('genres', False)
-        self.my_list_status: bool = kwargs.get('my_list_status', False)
+        # self.my_list_status: bool = kwargs.get('my_list_status', False)
+        self._my_list_status: ListStatusFields = self._generate_subclass(ListStatusFields, kwargs, 'my_list_status')
         self.pictures: bool = kwargs.get('pictures', False)
         self.background: bool = kwargs.get('background', False)
         self._related_anime: bool = self._generate_subclass(Fields, kwargs, 'related_anime')
@@ -108,9 +113,10 @@ class Fields(FieldsBase):
         self.average_episode_duration: bool = kwargs.get('average_episode_duration', False)
         self.rating: bool = kwargs.get('rating', False)
         self.studios: bool = kwargs.get('studios', False)
-        self.opening_themes: bool = kwargs.get('opening_theme', False)
-        self.ending_themes: bool = kwargs.get('ending_theme', False)
+        self.opening_themes: bool = kwargs.get('opening_themes', False)
+        self.ending_themes: bool = kwargs.get('ending_themes', False)
         self.statistics: bool = kwargs.get('statistics', False)
+        self.videos: bool = kwargs.get('videos', False)
 
         # manga related
         self.num_volumes: bool = kwargs.get('num_volumes', False)
@@ -118,8 +124,9 @@ class Fields(FieldsBase):
         self._authors: Union[AuthorFields, bool] = self._generate_subclass(AuthorFields, kwargs, 'authors')
         self.serialization: bool = kwargs.get('serialization', False)
 
-    def _generate_subclass(self, r_type, kwargs, key):
-        return r_type(**kwargs.get(key)) if isinstance(kwargs.get(key), dict) else kwargs.get(key) if isinstance(kwargs.get(key), r_type) else False if kwargs.get(key) is not True else r_type()
+        # endpoint specific
+        self._list_status: Union[ListStatusFields, bool] = self._generate_subclass(ListStatusFields, kwargs, 'list_status')
+        # self._list_status: bool = kwargs.get('ranking', False)
 
     @property
     def authors(self):
@@ -129,6 +136,14 @@ class Fields(FieldsBase):
     def authors(self, value):
         self._authors = self._generate_subclass(AuthorFields, {'authors': value}, 'authors')
 
+    @property
+    def list_status(self):
+        return self._list_status
+
+    @list_status.setter
+    def list_status(self, value):
+        self._list_status = self._generate_subclass(ListStatusFields, {'list_status': value}, 'list_status')
+
     @property
     def related_anime(self):
         return self._related_anime
@@ -153,6 +168,14 @@ class Fields(FieldsBase):
     def recommendations(self, value):
         self._recommendations = self._generate_subclass(Fields, {'recommendations': value}, 'recommendations')
 
+    @property
+    def my_list_status(self):
+        return self._my_list_status
+
+    @my_list_status.setter
+    def my_list_status(self, value):
+        self._my_list_status: ListStatusFields = self._generate_subclass(ListStatusFields, {'my_list_status': value}, 'my_list_status')
+
     @classmethod
     def empty(cls):
         return cls(id=False, title=False, main_picture=False)
@@ -201,7 +224,8 @@ class Fields(FieldsBase):
                                 "recommendations",
                                 "studios",
                                 "opening_theme",
-                                'ending_theme', ])
+                                'ending_theme',
+                                'videos',])
 
     @classmethod
     def manga(cls):
@@ -260,56 +284,84 @@ class ListStatusFields(FieldsBase):
     Helper fields class containing precise data for my_list_status
     """
     def __init__(self, **kwargs):
-        self.score: bool = kwargs.get('score', True)
-        self.status: bool = kwargs.get('status', True)
-        self.updated_at: bool = kwargs.get('updated_at', True)
-        self.start_date: bool = kwargs.get('start_date', False)
-        self.finish_date: bool = kwargs.get('finish_date', False)
         self.priority: bool = kwargs.get('priority', False)
         self.tags: bool = kwargs.get('tags', False)
         self.comments: bool = kwargs.get('comments', False)
 
-        # manga only
-        self.is_rereading: bool = kwargs.get('is_rereading', False)
-        self.num_chapters_read: bool = kwargs.get('num_chapters_read', False)
-        self.num_volumes_read: bool = kwargs.get('num_volumes_read', False)
         self.num_times_reread: bool = kwargs.get('num_times_reread', False)
         self.reread_value: bool = kwargs.get('reread_value', False)
 
-        # anime only
-        self.num_episodes_watched: bool = kwargs.get('num_episodes_watched', False)
-        self.is_rewatching: bool = kwargs.get('is_rewatching', False)
         self.num_times_rewatched: bool = kwargs.get('num_times_rewatched', False)
         self.rewatch_value: bool = kwargs.get('rewatch_value', False)
 
+        # DEPRECATED FIELDS - Always present in request
+        # self.score: bool = kwargs.get('score', True)
+        # self.status: bool = kwargs.get('status', True)
+        # self.updated_at: bool = kwargs.get('updated_at', True)
+        # self.start_date: bool = kwargs.get('start_date', False)
+        # self.finish_date: bool = kwargs.get('finish_date', False)
+        # self.is_rereading: bool = kwargs.get('is_rereading', False)
+        # self.num_chapters_read: bool = kwargs.get('num_chapters_read', False)
+        # self.num_volumes_read: bool = kwargs.get('num_volumes_read', False)
+        # self.num_episodes_watched: bool = kwargs.get('num_episodes_watched', False)
+        # self.is_rewatching: bool = kwargs.get('is_rewatching', False)
+
     @classmethod
     def empty(cls):
         return cls(score=False, status=False, updated_at=False)
 
-    @classmethod
-    def manga_base(cls):
-        """
-        Base fields for manga list status
-        """
-        return cls.from_list(['score', 'status', 'updated_at', 'is_rereading', 'num_chapters_read', 'num_volumes_read', 'start_date', 'finish_date'])
 
     @classmethod
     def manga_full(cls):
         """
         All fields for manga list status
         """
-        return cls.from_list(['score', 'status', 'updated_at', 'is_rereading', 'num_chapters_read', 'num_volumes_read', 'start_date', 'finish_date', 'priority', 'tags', 'comments', 'num_times_reread', 'reread_value'])
-
-    @classmethod
-    def anime_base(cls):
-        """
-        Base fields for anime list status
-        """
-        return cls.from_list(['score', 'status', 'updated_at', 'is_rewatching', 'num_episodes_watched'])
+        return cls.from_list(['priority', 'tags', 'comments', 'num_times_reread', 'reread_value'])
 
     @classmethod
     def anime_full(cls):
         """
         All fields for anime list status
         """
-        return cls.from_list(['score', 'status', 'updated_at', 'is_rewatching', 'num_episodes_watched', 'priority', 'tags', 'comments', 'num_times_rewatched', 'rewatch_value'])
+        return cls.from_list(['priority', 'tags', 'comments', 'num_times_rewatched', 'rewatch_value'])
+
+
+class UserFields(FieldsBase):
+    def __init__(self, **kwargs):
+        self.id: bool = kwargs.get("id", True)
+        self.name: bool = kwargs.get("name", True)
+        self.picture: bool = kwargs.get("picture", True)
+        self.gender: bool = kwargs.get("gender", True)
+        self.birthday: bool = kwargs.get("birthday", False)
+        self.location: bool = kwargs.get("location", True)
+        self.joined_at: bool = kwargs.get("joined_at", True)
+        self.anime_statistics: bool = kwargs.get("anime_statistics", True)
+        self.time_zone: bool = kwargs.get("time_zone", False)
+        self.is_supporter: bool = kwargs.get("is_supporter", False)
+
+    @classmethod
+    def basic(cls):
+        return cls(id=True,
+                   name=True,
+                   picture=True,
+                   anime_statistics=True)
+
+
+# Deprecated - This serves no purpose, you can't specify fields for this parameter
+# class AnimeStatisticsFields(FieldsBase):
+#     def __init__(self, **kwargs):
+#         self.num_items_watching: bool = kwargs.get("num_items_watching", False)
+#         self.num_items_completed: bool = kwargs.get("num_items_completed", False)
+#         self.num_items_on_hold: bool = kwargs.get("num_items_on_hold", False)
+#         self.num_items_dropped: bool = kwargs.get("num_items_dropped", False)
+#         self.num_items_plan_to_watch: bool = kwargs.get("num_items_plan_to_watch", False)
+#         self.num_items: bool = kwargs.get("num_items", False)
+#         self.num_days_watched: bool = kwargs.get("num_days_watched", False)
+#         self.num_days_watching: bool = kwargs.get("num_days_watching", False)
+#         self.num_days_completed: bool = kwargs.get("num_days_completed", False)
+#         self.num_days_on_hold: bool = kwargs.get("num_days_on_hold", False)
+#         self.num_days_dropped: bool = kwargs.get("num_days_dropped", False)
+#         self.num_days: bool = kwargs.get("num_days", False)
+#         self.num_episodes: bool = kwargs.get("num_episodes", False)
+#         self.num_times_rewatched: bool = kwargs.get("num_times_rewatched", False)
+#         self.mean_score: bool = kwargs.get("mean_score", False)
